@@ -1,7 +1,7 @@
 ### R code from vignette source 'msarc.Rnw'
 
 ###################################################
-### code chunk number 1: msarc.Rnw:69-89
+### code chunk number 1: msarc.Rnw:69-88
 ###################################################
 library(msarc)
 # load data
@@ -14,12 +14,11 @@ control <- msarc(control_df)
 # control)
 sample <- msarc.subtract(sample,control)
 # generate the list of GO terms
-sample <- msarc.findGOterms(sample)
+sample <- msarc.findGOterms(sample,minCount=5)
 # get the list as a data frame
 term_df <- msarc.getTerms(sample)
-term_df <- term_df[c("GO:0017076","GO:0030554","GO:0032553","GO:0032555",
-                     "GO:0032559","GO:0035639","GO:0036094","GO:0097159",
-                     "GO:0017111","GO:0016462"),]
+term_df <- term_df[c("GO:0008092","GO:0001883","GO:0043168","GO:1901265",
+                     "GO:0016787","GO:0017111"),]
 sample <- msarc.filterTerms(sample,term_df)
 # generate the plot
 msarc.plotSVG(sample,file="thing.svg")
